@@ -4,13 +4,14 @@ import inspect
 import sys
 import os
 import datetime
+import types
 
 # first party
-from .config import DsnConnection, Schema
+from .config import DsnConnection, Schema, Field
 from .query import Query
 from . import decorators
 
-__version__ = '0.9.10'
+__version__ = '0.9.18'
 
 interfaces = {}
 """holds all the configured interfaces"""
@@ -54,6 +55,7 @@ def configure_environ(dsn_env_name='PROM_DSN'):
         except KeyError:
             pass
 
+
 def configure(dsn):
     """
     configure an interface to be used to query a backend
@@ -77,6 +79,7 @@ def configure(dsn):
     set_interface(i, c.name)
     return i
 
+
 def set_interface(interface, name=''):
     """
     don't want to bother with a dsn? Use this method to make an interface available
@@ -86,6 +89,7 @@ def set_interface(interface, name=''):
     global interfaces
     interfaces[name] = interface
 
+
 def get_interface(name=''):
     """
     get an interface that was created using configure()
@@ -95,6 +99,7 @@ def get_interface(name=''):
     global interfaces
     return interfaces[name]
 
+
 class Orm(object):
     """
     this is the parent class of any model Orm class you want to create that can access the db
@@ -208,12 +213,23 @@ class Orm(object):
         """wrapper property method to return the updated timestamp"""
         return getattr(self, self.schema._updated, None)
 
-    def __init__(self, **fields):
+    @property
+    def fields(self):
+        """
+        return all the fields and their raw values for this Orm instance. This
+        property returns a dict with the field names and their current values
+
+        if you want to control the values for outputting to an api, use .jsonable()
+        """
+        return {k:getattr(self, k, None) for k in self.schema.fields}
+
+    def __init__(self, fields=None, **fields_kwargs):
+        fields = self._normalize_dict(fields, fields_kwargs)
         self.reset_modified()
         self.modify(fields)
 
     @classmethod
-    def normalize(cls, fields):
+    def normalize(cls, fields=None, **fields_kwargs):
         """
         return only the fields in the fields dict that are also in schema
 
@@ -223,6 +239,7 @@ class Orm(object):
         return -- dict -- the field/values that are in cls.schema
         """
         rd = {}
+        fields = cls._normalize_dict(fields, fields_kwargs)
         s = cls.schema
         for field_name, field_val in fields.iteritems():
             if field_name in s.fields:
@@ -235,30 +252,28 @@ class Orm(object):
         return rd
 
     @classmethod
-    def create(cls, fields=None, **field_kwargs):
+    def create(cls, fields=None, **fields_kwargs):
         """
         create an instance of cls with the passed in fields and set it into the db
 
         fields -- dict -- field_name keys, with their respective values
-        **field_kwargs -- dict -- if you would rather pass in fields as name=val, that works also
+        **fields_kwargs -- dict -- if you would rather pass in fields as name=val, that works also
         """
-        if not fields: fields = {}
-        fields.update(field_kwargs)
+        fields = cls._normalize_dict(fields, fields_kwargs)
         instance = cls(**cls.normalize(fields))
         instance.set()
         return instance
 
     @classmethod
-    def populate(cls, fields=None, **field_kwargs):
+    def populate(cls, fields=None, **fields_kwargs):
         """
         create an instance of cls with the passed in fields but don't set it into the db or mark the passed
         in fields as modified, this is used by the Query class to hydrate objects
 
         fields -- dict -- field_name keys, with their respective values
-        **field_kwargs -- dict -- if you would rather pass in fields as name=val, that works also
+        **fields_kwargs -- dict -- if you would rather pass in fields as name=val, that works also
         """
-        if not fields: fields = {}
-        fields.update(field_kwargs)
+        fields = cls._normalize_dict(fields, fields_kwargs)
         instance = cls(**fields)
         instance.reset_modified()
         return instance
@@ -309,7 +324,11 @@ class Orm(object):
         ret = False
 
         _id_name = self.schema.pk
-        _id = self.pk
+        # we will only use the primary key if it hasn't been modified
+        _id = None
+        if _id_name not in self.modified_fields:
+            _id = self.pk
+
         if _id:
             ret = self.update()
         else:
@@ -346,11 +365,9 @@ class Orm(object):
 
         return fields
 
-    def modify(self, fields=None, **field_kwargs):
+    def modify(self, fields=None, **fields_kwargs):
         """update the fields of this instance with the values in dict fields"""
-        if not fields: fields = {}
-        fields.update(field_kwargs)
-
+        fields = self._normalize_dict(fields, fields_kwargs)
         for field_name, field_val in fields.iteritems():
             setattr(self, field_name, field_val)
 
@@ -368,9 +385,9 @@ class Orm(object):
         """
         self.modified_fields = set()
 
-    def jsonable(self):
+    def jsonable(self, *args, **options):
         """
-        return a version of this instance that can be jsonified
+        return a public version of this instance that can be jsonified
 
         Note that this does not return _id, _created, _updated, the reason why is
         because lots of times you have a different name for _id (like if it is a 
@@ -378,7 +395,8 @@ class Orm(object):
         didn't want to make assumptions
 
         note 2, I'm not crazy about the name, but I didn't like to_dict() and pretty
-        much any time I need to convert the object to a dict is for json
+        much any time I need to convert the object to a dict is for json, I kind of
+        like dictify() though, but I've already used this method in so many places
         """
         d = {}
         def default_field_type(field_type):
@@ -409,10 +427,22 @@ class Orm(object):
 
         return d
 
+    @classmethod
+    def _normalize_dict(cls, fields, fields_kwargs):
+        """lot's of methods take a dict or kwargs, this combines those"""
+        if not fields:
+            fields = {}
+
+        if fields_kwargs:
+            fields.update(fields_kwargs)
+
+        return fields
+
     @classmethod
     def install(cls):
         """install the Orm's table using the Orm's schema"""
         return cls.interface.set_table(cls.schema)
 
+
 configure_environ()
 
