@@ -383,11 +383,24 @@ class Query(object):
 
         return field_vals
 
+    def get_pks(self, field_vals):
+        """convenience method for running in__id([...]).get() since this is so common"""
+        field_name = self.orm.schema.pk
+        return self.in_field(field_name, field_vals).get()
+
     def get_pk(self, field_val):
         """convenience method for running is__id(_id).get_one() since this is so common"""
         field_name = self.orm.schema.pk
         return self.is_field(field_name, field_val).get_one()
 
+    def first(self):
+        """convenience method for running asc__id().get_one()"""
+        return self.asc__id().get_one()
+
+    def last(self):
+        """convenience method for running desc__id().get_one()"""
+        return self.desc__id().get_one()
+
     def count(self):
         """return the count of the criteria"""
         return self._query('count')
@@ -405,9 +418,19 @@ class Query(object):
         """remove fields matching the where criteria"""
         return self._query('delete')
 
-    def get_query(self, query_str, *query_args, **query_options):
+    def raw(self, query_str, *query_args, **query_options):
         """
-        use the interface query method to pass in your own raw query
+        use the interface.query() method to pass in your own raw query without
+        any processing
+
+        NOTE -- This will allow you to make any raw query and will usually return
+        raw results, it won't wrap those results in a prom.Orm iterator instance
+        like other methods like .all() and .get()
+
+        query_str -- string -- the raw query for whatever the backend interface is
+        query_args -- list -- if you have named parameters, you can pass in the values
+        **query_options -- dict -- key:val options for the backend, these are very backend specific
+        return -- mixed -- depends on the backend and the type of query
         """
         i = self.orm.interface
         return i.query(query_str, *query_args, **query_options)
